@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-fancy-fill-paragraph
 ;; Keywords: convenience
-;; Package-Version: 20260215.731
-;; Package-Revision: 2e5861a4f663
+;; Package-Version: 20260218.1058
+;; Package-Revision: 68e3e903ec94
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -938,7 +938,8 @@ and re-adds the prefix to each output line."
         (save-excursion
           ;; Use `replace-region-contents' to minimize undo differences
           ;; compared with delete-region + insert.
-          (replace-region-contents beg end result))))))
+          ;; NOTE: when emacs 30.x is dropped, `result' can be passed in directly.
+          (replace-region-contents beg end (lambda () result)))))))
 
 
 ;; ---------------------------------------------------------------------------
